app.rocksky.equalizer.* — saved EQ presets (app.rocksky.equalizer records in the caller's repo).
Units are rockbox's internal ones: band frequency in Hz, gain in tenths of dB (30 = +3.0 dB), q × 10 (7 = Q 0.7); precut in tenths of dB (-240..0).
app.rocksky.equalizer.* — saved EQ presets (app.rocksky.equalizer records in the caller's repo). Units are rockbox's internal ones: band frequency in Hz, gain in tenths of dB (30 = +3.0 dB), q × 10 (7 = Q 0.7); precut in tenths of dB (-240..0).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |