Endpoints under app.rocksky.song.*
Endpoints under app.rocksky.song.*
(create-song client
{:keys [title artist album-artist album duration mb-id isrc
album-art track-number release-date year disc-number
lyrics]})Create a new song.
Required: :title :artist :album :album-artist.
Optional: :duration :mb-id :isrc :album-art :track-number
:release-date :year :disc-number :lyrics.
Create a new song. Required: `:title` `:artist` `:album` `:album-artist`. Optional: `:duration` `:mb-id` `:isrc` `:album-art` `:track-number` `:release-date` `:year` `:disc-number` `:lyrics`.
(get-song client)(get-song client {:keys [uri mbid isrc spotify-id]})Get a song by URI, MusicBrainz ID, ISRC, or Spotify track ID.
Optional: :uri :mbid :isrc :spotify-id.
Get a song by URI, MusicBrainz ID, ISRC, or Spotify track ID. Optional: `:uri` `:mbid` `:isrc` `:spotify-id`.
(get-song-recent-listeners client {:keys [uri limit offset]})Get a song's recent listeners.
Required: :uri. Optional: :limit :offset.
Get a song's recent listeners. Required: `:uri`. Optional: `:limit` `:offset`.
(get-songs client)(get-songs client {:keys [limit offset genre mbid isrc spotify-id]})List songs.
Optional: :limit :offset :genre :mbid :isrc :spotify-id.
List songs. Optional: `:limit` `:offset` `:genre` `:mbid` `:isrc` `:spotify-id`.
(match-song client {:keys [title artist mb-id isrc]})Match a song against Rocksky and external providers to resolve a canonical track/artist/album.
Required: :title :artist. Optional: :mb-id :isrc.
Match a song against Rocksky and external providers to resolve a canonical track/artist/album. Required: `:title` `:artist`. Optional: `:mb-id` `:isrc`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |