rocksky.core

Convenience facade — pulls the most common bits to a single namespace.

(require '[rocksky.core :as rs])

(def c (rs/client {:token "..."}))
(rs/get-profile c {:did "alice.rocksky.app"})

For everything else, require the per-resource namespaces directly (rocksky.actor, rocksky.album, rocksky.scrobble, ...).

Convenience facade — pulls the most common bits to a single namespace.

```
(require '[rocksky.core :as rs])

(def c (rs/client {:token "..."}))
(rs/get-profile c {:did "alice.rocksky.app"})
```

For everything else, require the per-resource namespaces directly
(`rocksky.actor`, `rocksky.album`, `rocksky.scrobble`, ...).
raw docstring

clientclj

source

create-scrobbleclj

source

get-profileclj

source

get-scrobblesclj

source

get-statsclj

source

get-wrappedclj

source

procedureclj

source

queryclj

source

source

with-base-urlclj

source

with-headersclj

source

with-tokenclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries